Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(82)

Unified Diff: pkg/dartino/lib/dartino.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/dartino/lib/_sdkext ('k') | pkg/dartino/pubspec.yaml » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/dartino/lib/dartino.dart
diff --git a/pkg/fletch/lib/fletch.dart b/pkg/dartino/lib/dartino.dart
similarity index 85%
rename from pkg/fletch/lib/fletch.dart
rename to pkg/dartino/lib/dartino.dart
index 48b36cf6f299ec60220548fd39645845c952bc26..597d381f8dafec8523d82ce4b7d5fc54f2f8e21d 100644
--- a/pkg/fletch/lib/fletch.dart
+++ b/pkg/dartino/lib/dartino.dart
@@ -2,12 +2,12 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
/// Fletch utility package.
///
/// This is a preliminary API.
-library fletch;
+library dartino;
-import 'dart:fletch.ffi';
+import 'dart:dartino.ffi';
import 'package:ffi/ffi.dart';
final ForeignFunction _getVersion = ForeignLibrary.main.lookup('GetVersion');
« no previous file with comments | « pkg/dartino/lib/_sdkext ('k') | pkg/dartino/pubspec.yaml » ('j') | no next file with comments »
@@ -2,12 +2,12 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-/// Fletch utility package.
+/// Dartino utility package.
///
/// This is a preliminary API.

Powered by Google App Engine
This is Rietveld 408576698